/* initng-conf-gtk, the gtk configuration program for initng
 * Copyright (C) 2006 Daniel Malmgren <dm@mensa.se>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#include "ngchandler.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

char *ngc_send_and_reply(const char c, const char *opt) {
  reply *rep = NULL;
  char *answer = NULL;

  rep = ngcclient_send_command(SOCKET_4_FILENAME_REAL, c, NULL, opt);

  if (ngcclient_error) {
    fprintf(stderr, "%s\n", ngcclient_error);
    return NULL;
  }

  if (!rep) {
    fprintf(stderr, _("Command failed.\n"));
    return NULL;
  }

  answer = ngcclient_reply_to_string(rep, FALSE);

  free(rep);
  return answer;
}

void ngc_send(const char c, const char *opt) {
  char *string = NULL;

  string = ngc_send_and_reply(c, opt);
  if (string)
    free(string);
}

void start_service(const char *name) {
  if(strrchr(name, '*')) {
    gchar *newname = malloc(strlen(name));
    xml_start_service = glade_xml_new(FILENAME, "start_service", NULL);
    if(!xml_start_service)
      xml_start_service = glade_xml_new(SECONDARY_FILENAME,
				       "start_service", NULL);
    GtkWidget *start_service_name_entry = glade_xml_get_widget(xml_start_service,
							       "start_service_name_entry");
    strncpy(newname, name, strlen(name)-1);
    newname[strlen(name)-1] = 0;
    gtk_entry_set_text(GTK_ENTRY(start_service_name_entry), newname);
    gtk_editable_set_position(GTK_EDITABLE(start_service_name_entry), -1);
    glade_xml_signal_autoconnect(xml_start_service);
    free(newname);
  } else {
    ngc_send('u', name);
  }
}

void stop_service(const char *name) {
  ngc_send('d', name);
}

void restart_service(const char *name) {
  ngc_send('r', name);
}

void zap_service(const char *name) {
  ngc_send('z', name);
}
